@@ -54,7 +54,7 @@ _COUNTRIES = {
     40: ["Lithuania", "COUNTRY_LITHUANIA"],
     41: ["China", "COUNTRY_CHINA"],
     42: ["Philipines", "COUNTRY_PHILIPPINES"],
-    43: ["Brazil", "COUNTRY_BRAZIL"],
+    43: ["Brazil 220/380V)", "COUNTRY_BRAZIL"],
     44: ["Mexico 220V", "COUNTRY_MEXICO_220"],
     45: ["Mexico 277V", "COUNTRY_MEXICO_277"],
     46: ["Romania", "COUNTRY_ROMANIA"],
@@ -168,7 +168,7 @@ _COUNTRIES = {
     154: ["Argentina (Commercial)", "COUNTRY_ARGENTINA_COMMERCIAL"],
     155: ["Sweden MV", "COUNTRY_SWEDEN_MV"],
     156: ["Vietnam", "COUNTRY_VIETNAM"],
-    157: ["Brzail 127V-220V", "COUNTRY_BRAZIL_127V_220V"],
+    157: ["Brazil 127/220V", "COUNTRY_BRAZIL_127V_220V"],
     158: ["Barbados 220V", "COUNTRY_BARBADOS_200"],
     159: ["ISO-NE 208V", "COUNTRY_US_NEW_ENGLAND_208"],
     160: ["ISO-NE 240V", "COUNTRY_US_NEW_ENGLAND_240"],
@@ -177,7 +177,7 @@ _COUNTRIES = {
     163: ["ISO-NE 277V", "COUNTRY_US_NEW_ENGLAND_277"],
     164: ["Korea Low DC", "COUNTRY_KOREA_LOW_DC"],
     165: ["Israel 480 MV", "COUNTRY_ISRAEL_480V_MV"],
-    166: ["Brzail 277V", "COUNTRY_BRAZIL_277"],
+    166: ["Brazil 277/480V", "COUNTRY_BRAZIL_277"],
     167: ["Hungary EON", "COUNTRY_HUNGARY_EON"],
     168: ["Spain (Islands)", "COUNTRY_SPANISH_ISLANDS"],
     169: ["Peru", "COUNTRY_PERU"],
@@ -189,7 +189,11 @@ _COUNTRIES = {
     175: ["Hong Kong", "COUNTRY_HONG_KONG"],
     176: ["Uruguay", "COUNTRY_URUGUAY"],
     177: ["Italy A68", "COUNTRY_ITALIY_A68"],
-    178: ["Estonia", "COUNTRY_ESTONIA"]
+    178: ["Estonia", "COUNTRY_ESTONIA"],
+    179: ["Mauritius 2", "COUNTRY_MAURITIUS_2"],
+    180: ["Surinam", "COUNTRY_SURINAM"],
+    181: ["Western Power", "COUNTRY_WESTERN_POWER"],
+    182: ["India (Kerala)", "COUNTRY_INDIA_KERALA"]
 }
 Countries = enum.Enum(
     value="Countries",
@@ -211,7 +215,8 @@ _STATUS = {
     7: ["Night Mode", "NIGHT_MODE"],
     8: ["Grid Monitoring", "GRID_MONITORING"],
     9: ["Idle", "IDLE"],
-    10: ["Grid Pairing", "GRM_PAIRING"]
+    10: ["Grid Pairing", "GRM_PAIRING"],
+    11: ["PID Rectification", "PID_RECTIFICATION"]
 }
 Status = enum.Enum(
     value="Status",
@@ -386,10 +391,49 @@ class OperationMode(enum.Enum):
 
 class LanNetStatus(enum.Enum):
     LAN_UNKNOWN = 0
+    LAN_CABLE_NOT_CONNECTED = 1
+    LAN_ERROR_DHCP = 2
+    LAN_NO_INTERNET_CONNECTION = 3
+    LAN_ERROR_DNS = 4
+    LAN_CONNECTING_TO_SERVER = 5
+    LAN_WAITING_FOR_SERVER_RESPONSE = 6
+    LAN_SERVER_RESPONDED = 7
 
 
 class WifiNetStatus(enum.Enum):
     WIFI_UNKNOWN = 0
+    WIFI_NOT_CONNECTED = 1
+    WIFI_CONNECTION_IN_PROGRESS = 2
+    WIFI_ERROR_WRONG_PASSWORD = 3
+    WIFI_ERROR_UNREACHABLE = 4
+    WIFI_ERROR_DHCP = 5
+    WIFI_ERROR_CONNECTION_OTHER = 6
+    WIFI_NO_INTERNET_CONNECTION = 7
+    WIFI_ERROR_DNS = 8
+    WIFI_CONNECTING_TO_SERVER = 9
+    WIFI_WAITING_FOR_SERVER_RESPONSE = 10
+    WIFI_SERVER_RESPONDED = 11
+
+
+class RS485SlaveNetStatus(enum.Enum):
+    RS485_SLAVE_UNKNOWN = 0
+    RS485_SLAVE_NOT_CONFIGURED = 1
+    RS485_SLAVE_NO_MASTER = 2
+    RS485_SLAVE_NO_GRANT_RECEIVED = 3
+    RS485_SLAVE_CONNECTED_TO_MASTER = 4
+    RS485_SLAVE_SERVER_RESPONDED = 5
+
+
+class ZigbeeSlaveNetStatus(enum.Enum):
+    ZB_SLAVE_UNKNOWN = 0
+    ZB_SLAVE_NOT_DETECTED = 1
+    ZB_DETECTION_IN_PROGRESS = 2
+    ZB_INIT_MODULE = 3
+    ZB_SLAVE_NOT_CONFIGURED = 4
+    ZB_SLAVE_DISASSOCIATED = 5
+    ZB_SLAVE_NO_COMM_WITH_COORDINATOR = 6
+    ZB_SLAVE_CONNECTED_TO_COORDINATOR = 7
+    ZB_SLAVE_SERVER_RESPONDED = 8
 
 
 class CellNetStatus(enum.Enum):
@@ -415,3 +459,66 @@ class CellNetStatus(enum.Enum):
     CELL_ACTIVATING_ERROR = 19
     CELL_CONNECTING_TO_SERVER = 20
     CELL_CONNECTED = 21
+    CELL_SERVER_RESPONDED = 22
+
+
+class ControllerTypes(enum.Enum):
+    ORTIA = 0
+    VENUS_DSP1 = 1
+    VENUS_DSP2 = 2
+    JUPITER_DSP1 = 3
+    JUPITER_DSP2 = 4
+    VEGA_DSP = 5
+    DISP_CTRL = 6
+    FAN_CTRL = 7
+    VENUS3_DSP1 = 8
+    VENUS3_DSP2 = 9
+    VENUS_LITE_DSP1 = 10
+    VENUS_LITE_DSP2 = 11
+    JUPITER_DSP1_BOOTLOADER = 12
+    EVSE = 13
+    SE_DCDC = 14
+    METER = 15
+    LG_DCDC = 16
+    LG_BMS = 17
+    HG2 = 18
+    JUPITER_SE_DSP1 = 19
+    JUPITER_SE_DSP2 = 20
+    BUI = 21
+    FOUR_BOX = 22
+    VENUS3_SE_DSP1 = 23
+    VENUS3_SE_DSP2 = 24
+
+
+class ProductTypes(enum.Enum):
+    VENUS = 0
+    JUPITER = 1
+    VEGA = 2
+    CCG = 3
+    GEMINI = 4
+    SATURN = 5
+    MARS = 6
+    VOYAGER = 7
+    VENUS3 = 8
+    JUMBO_JUPITER = 9
+    VENUS_LITE = 10
+    CCG_UNUSED = 11
+    FFG = 12
+    ZIGBEE_GATEWAY = 13
+    EVSE_SA = 14
+    WIFI_REPEATER = 15
+    WIFI_GATEWAY = 16
+    PRODUCT_TYPE_WATER_HEATER = 17
+    PRODUCT_TYPE_CCG_GPU = 18
+    PRODUCT_TYPE_METER = 19
+    PRODUCT_TYPE_JJ_4BOX = 20
+    PRODUCT_TYPE_BUI = 21
+    PRODUCT_TYPE_NONE = 22
+
+
+class UnitPosition(enum.Enum):
+    UNKNOWN = 0
+    LEFT = 1
+    CENTER = 2
+    RIGHT = 3
+    PRIMARY = 4
